import json
import os
import requests
import threading
import time
import sys
import queue
from define import *
from main_paras import api_result_que
import main_paras

class GetReportEmail(threading.Thread):
    def __init__(self, *args):
        threading.Thread.__init__(self)
        self.passToken = args[0]
    def run(self):
        excReason=''
        api_result_que.clear()
        for i in range(API_RETRY_TIME):
            try:
                service = "/lsreportemailsetting/get"
                url = baseUrl + service
                payload = json.dumps({
                    "passtoken": self.passToken
                })
                headers = {
                  'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
                  'Content-Type': 'application/json'
                }
                print(payload)
                response = requests.request("POST", url, headers=headers, data=payload)
                print(response.text)
                parsing=json.loads(response.text)
                if parsing[CODE] == RESPONSE_SUCCESS:
                    rsp =[NON_SLOT_INDEX, API_RESPONSE_SUCCESS,  parsing[RSLT]['reportemail1'], parsing[RSLT]['reportemail2']]
                    #print('put in queue', rsp)
                          
                    
                    api_result_que.put( rsp )
                else:
                    api_result_que.put( [NON_SLOT_INDEX, API_RESPONSE_FAIL,  parsing[CODE], parsing[RSLT]] )
                return
            except Exception as e:
                excReason = "getReportEmail Exception"
                print(e)
            time.sleep(API_RETRY_SLEEP)
            
        else:
            api_result_que.put( [NON_SLOT_INDEX, API_RESPONSE_FAIL,  excReason, 'time out'] )
            
def test():
    notifyQue=queue.Queue()
    signIn=SignUp(notifyQue)
    signIn.start()
    
    while True:
        notify = notifyQue.get()
        print(notify)
        notifyQue.task_done()
        time.sleep(0.1)
        if not SignUp.is_alive():
            break;
    print("sign up done")
    

if __name__ == "__main__":
    test()    



import threading
import time
import queue
import sys

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)

from communication.ln_web import sendToApi
from communication.sign_in import SignIn
from communication.sign_up import SignUp
from communication.change_password import ChgPsw
from communication.forgot_password import ForgotPassword
from communication.test_report_email import TestReportEmail
from communication.get_report_email import GetReportEmail
from communication.get_report import GetReport
from define import *
import main_paras
    
class CommunicationThread (threading.Thread):
    def __init__(self, threadID, name, qForCom, qForResult):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.qForCom=qForCom
        self.qForResult=qForResult
        self.notifyQue=queue.Queue()
        self.passToken=''
        
    def signIn(self, user, password):        
        signIn=SignIn(self.notifyQue, user, password)
        signIn.start()
        notify = self.notifyQue.get()
        if notify[1] == SIGN_IN_SUCCESS:
            self.passToken = notify[2]
        print(notify)
        self.notifyQue.task_done()
        signIn.join()
        print("sign in done")

    def signUp(self, user, password, firstName, lastName):        
        sign_up=SignUp(user, password, firstName, lastName)
        sign_up.start()
        sign_up.join()
        print("sign up done")

    def chgPsw(self, token, password, newPassword):        
        chg_psw=ChgPsw(token, password, newPassword)
        chg_psw.start()
        chg_psw.join()
        print("change password done")

    def forgotPsw(self, email):        
        forgot_psw=ForgotPassword( email)
        forgot_psw.start()
        forgot_psw.join()
        print("forgot password done")
        
    def testReportEmail(self, token, email_1, email_2):        
        test_report_email=TestReportEmail(token, email_1, email_2)
        test_report_email.start()
        test_report_email.join()
        print("test report email set done")

    def getReportEmail(self, token):        
        get_report_email=GetReportEmail(token)
        get_report_email.start()
        get_report_email.join()
        print("get report email done")

    def getReport(self, token):        
        get_report=GetReport(token)
        get_report.start()
        get_report.join()
        print("get report request sent")

    def webApi(self):
        while True:
            image=self.qForCom.get()
            if image == CLOSE_NOW:
                break;
            if type(image) ==list:
                print(image)
                if image[0] == SIGN_IN:    #[SIGN_IN, user, password]
                    self.signIn(image[1],image[2])
                    continue
                elif image[0] == SIGN_UP:    #[SIGN_UP, user, password, firstName, lastName]
                    self.signUp(image[1], image[2], image[3], image[4])
                    continue
                elif image[0] == CHG_PSW:    #[CHG_PSW, password, new_password]
                    self.chgPsw(main_paras.sign_in_token, image[1], image[2])
                    continue
                elif image[0] == FORGOT_PSW:    #[FORGOT_PSW, email]
                    self.forgotPsw(image[1])
                    continue
                elif image[0] == TEST_REPORT_EMAIL:    #[TEST_REPORT, email_1, email_2]
                    self.testReportEmail(main_paras.sign_in_token, image[1], image[2])
                    continue
                elif image[0] == GET_REPORT_EMAIL:    #[GET_REPORT_EMAIL, passtoken]
                    self.getReportEmail(main_paras.sign_in_token)
                    continue
                elif image[0] == GET_REPORT:    #[GET_REPORT, passtoken]
                    self.getReport(main_paras.sign_in_token)
                    continue
            sendToApi(image, self.qForResult, self.passToken, [main_paras.test_place, main_paras.test_city, main_paras.test_country])
            self.qForCom.task_done()
        
    def run(self):
        super().run()
        print("communication thread start.")
        #self.aiServer()
        self.webApi()
  
#################### Test ####################
def com_test():
    qForCom=queue.Queue()
    qForResult = queue.Queue()
    com=CommunicationThread(3,"communication",qForCom, qForResult)
    com.start()
    
    time.sleep(2)
    

if __name__ == "__main__":
    com_test()   



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

import launcher_resource


class _Launcher(QtWidgets.QMainWindow):
    def __init__(self,parent=None):
        super(_Launcher, self).__init__(parent)

        loadUi(os.path.join(currentdir,'launcher.ui'),self)
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        
#        QtCore.QTimer.singleShot(100, self.tryToConnect)

    def config(self):
        try:
            
##            style = '.QWidget{background-image:url(:/slot/png/slot/'+self.slotBasic[page][0]+ ');border:0px}'
##            self.centralwidget.setStyleSheet(style)
            pass
        except Exception as error:
            print(error)

    def closeEvent(self,event):
        print("_WifiPassword is closing")
#        main_paras.type_in_que.put([self.passwordIsSet, self.newPassword])
        
    

if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)
#    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)

    #QtWidgets.QMainWindow
    window=_Launcher()
    window.show()

    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'spotii.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(750, 485)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.slot_0 = QtWidgets.QStackedWidget(self.centralwidget)
        self.slot_0.setGeometry(QtCore.QRect(90, 130, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_0.sizePolicy().hasHeightForWidth())
        self.slot_0.setSizePolicy(sizePolicy)
        self.slot_0.setStyleSheet("")
        self.slot_0.setObjectName("slot_0")
        self.empty = QtWidgets.QWidget()
        self.empty.setStyleSheet("background-image: url(:/empty_slot/png/slot/spot-slot-empty.png);")
        self.empty.setObjectName("empty")
        self.slot_0.addWidget(self.empty)
        self.detecting = QtWidgets.QWidget()
#        self.detecting.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/detecting 1.png);")
        #self.detecting.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/detecting 1.png);")
        #self.detecting.setStyleSheet(".QWidget{background-image:" + "url(" + ":/slot_1/png/slot/slot_1/detecting 1.png" + ");" + "border:0px}")
        self.detecting.setStyleSheet(".QWidget{background-image:url(:/slot_1/png/slot/slot_1/detecting 1.png);border:0px}")
        self.detecting.setObjectName("detecting")
        self.timer = QtWidgets.QPushButton(self.detecting)
        self.timer.setGeometry(QtCore.QRect(20, 140, 63, 16))
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.timer.setFont(font)
        self.timer.setStyleSheet("QPushButton{background-color: transparent; border:0; color : white}")
        self.timer.setObjectName("timer")
        self.casset_id = QtWidgets.QLabel(self.detecting)
        self.casset_id.setGeometry(QtCore.QRect(0, 200, 101, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.casset_id.sizePolicy().hasHeightForWidth())
        self.casset_id.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.casset_id.setFont(font)
        self.casset_id.setStyleSheet("QLabel{background-color: transparent; border:0; color : white}")
        self.casset_id.setObjectName("casset_id")
        self.slot_0.addWidget(self.detecting)
        self.warning = QtWidgets.QWidget()
        self.warning.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/warning - 1.png);")
        self.warning.setObjectName("warning")
        self.slot_0.addWidget(self.warning)
        self.positive = QtWidgets.QWidget()
        self.positive.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/positive 1.png);")
        self.positive.setObjectName("positive")
        self.slot_0.addWidget(self.positive)
        self.negative = QtWidgets.QWidget()
        self.negative.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/negative - 1.png);")
        self.negative.setObjectName("negative")
        self.slot_0.addWidget(self.negative)
        self.invalid = QtWidgets.QWidget()
        self.invalid.setStyleSheet("QWidget{background-image:url(:/slot_1/png/slot/slot_1/invalid - 1.png);border:0px}")
        self.invalid.setObjectName("invalid")
        self.slot_0.addWidget(self.invalid)
        self.widget = QtWidgets.QWidget(self.centralwidget)
        self.widget.setGeometry(QtCore.QRect(30, 20, 445, 49))
        self.widget.setStyleSheet("background-image: url(:/title_background/png/title/rectangle.png);")
        self.widget.setInputMethodHints(QtCore.Qt.ImhNone)
        self.widget.setObjectName("widget")
        self.gridLayout = QtWidgets.QGridLayout(self.widget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setHorizontalSpacing(5)
        self.gridLayout.setObjectName("gridLayout")
        self.logo = QtWidgets.QLabel(self.widget)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/logo/png/title/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.gridLayout.addWidget(self.logo, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(35, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 1, 1, 1)
        self.help = MyToolButton(self.widget)
        self.help.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.help.setFont(font)
        self.help.setInputMethodHints(QtCore.Qt.ImhNone)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.help.setIcon(icon)
        self.help.setIconSize(QtCore.QSize(24, 18))
        self.help.setCheckable(True)
        self.help.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.help.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.help.setObjectName("help")
        self.gridLayout.addWidget(self.help, 0, 2, 1, 1)
        self.wifi = MyToolButton(self.widget)
        self.wifi.setEnabled(True)
        self.wifi.setInputMethodHints(QtCore.Qt.ImhNone)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.wifi.setIcon(icon1)
        self.wifi.setIconSize(QtCore.QSize(24, 18))
        self.wifi.setCheckable(True)
        self.wifi.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.wifi.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.wifi.setObjectName("wifi")
        self.gridLayout.addWidget(self.wifi, 0, 3, 1, 1)
        self.volume = MyToolButton(self.widget)
        self.volume.setEnabled(True)
        self.volume.setInputMethodHints(QtCore.Qt.ImhNone)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon2.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.volume.setIcon(icon2)
        self.volume.setIconSize(QtCore.QSize(24, 18))
        self.volume.setCheckable(True)
        self.volume.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.volume.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.volume.setObjectName("volume")
        self.gridLayout.addWidget(self.volume, 0, 4, 1, 1)
        self.calendar = MyToolButton(self.widget)
        self.calendar.setEnabled(True)
        self.calendar.setInputMethodHints(QtCore.Qt.ImhNone)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/calendar/png/title/spot-icons-calendar-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon3.addPixmap(QtGui.QPixmap(":/calendar/png/title/spot-icons-calendar-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.calendar.setIcon(icon3)
        self.calendar.setIconSize(QtCore.QSize(24, 18))
        self.calendar.setCheckable(True)
        self.calendar.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.calendar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.calendar.setObjectName("calendar")
        self.gridLayout.addWidget(self.calendar, 0, 5, 1, 1)
        self.setting = MyToolButton(self.widget)
        self.setting.setEnabled(True)
        self.setting.setInputMethodHints(QtCore.Qt.ImhNone)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.setting.setIcon(icon4)
        self.setting.setIconSize(QtCore.QSize(24, 18))
        self.setting.setCheckable(True)
        self.setting.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.setting.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.setting.setObjectName("setting")
        self.gridLayout.addWidget(self.setting, 0, 6, 1, 1)
        self.bluetooth = MyToolButton(self.widget)
        self.bluetooth.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.bluetooth.setFont(font)
        self.bluetooth.setInputMethodHints(QtCore.Qt.ImhNone)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/bluetooth/png/title/spot-icons-bluetooth-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon5.addPixmap(QtGui.QPixmap(":/bluetooth/png/title/spot-icons-bluetooth-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.bluetooth.setIcon(icon5)
        self.bluetooth.setIconSize(QtCore.QSize(24, 18))
        self.bluetooth.setCheckable(True)
        self.bluetooth.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.bluetooth.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.bluetooth.setObjectName("bluetooth")
        self.gridLayout.addWidget(self.bluetooth, 0, 7, 1, 1)
        self.slot_0.raise_()
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.slot_0.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.timer.setText(_translate("MainWindow", "5:30"))
        self.casset_id.setText(_translate("MainWindow", "La0000009"))
from MyToolButton import MyToolButton
import title_rc


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-
import queue
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parentdir = os.path.dirname(currentdir)
print('current dir',currentdir)
print('parent dir', parentdir)
sys.path.insert(0, currentdir)

from define import *
from communication.communication import CommunicationThread
from on_off.on_off import OnOffThread
from test_handler.test_chip_handler import TestChipHandlerThread
from vkeyboard import handleVisibleChanged
LOCAL_LAUCHER_FOLDER = '/home/pi/app/spotii/launcher'
LOCAL_LAUCHER_CHK_FILE = LOCAL_LAUCHER_FOLDER+'/chk_sum.md5'
DESK_TOP = '/home/pi/Desktop'
def preStart():
    try:
        import shutil
        os.makedirs(LOCAL_LAUCHER_FOLDER, exist_ok =True)
        os.makedirs(IMG_PATH, exist_ok =True)
        
        lib_path = os.path.dirname(__file__)
        
        
        print('main directory:', lib_path)
        if lib_path == '':
            pass
        else:
            upgrade_launcher = False
            if os.path.exists(LOCAL_LAUCHER_CHK_FILE):
                with open(lib_path+'/launcher/'+'chk_sum.md5',"rb") as lib_file:
                    lib_check_sum=lib_file.read()
                    print('lib check sum ',lib_check_sum)
                with open(LOCAL_LAUCHER_CHK_FILE,"rb") as local_file:
                    local_check_sum=local_file.read()
                    print('local check sum ',local_check_sum)
                if lib_check_sum != local_check_sum:
                    upgrade_launcher = True
            else:
                upgrade_launcher = True
                
            if upgrade_launcher:
                print('upgrading launcher..')
                src=os.path.join(lib_path,'launcher')
                for item in os.listdir(src):
                    #print(item)
                    if item.endswith('.sh'):
                        print('Copying to deskTop', item)
                        shutil.copy(os.path.join(src, item), os.path.join(DESK_TOP, item))
                    elif item.endswith('.py') or item.endswith('.md5'):
                        print('Copying to local laucher folder',item)
                        shutil.copy(os.path.join(src, item), os.path.join(LOCAL_LAUCHER_FOLDER, item))
    except Exception as e:
        print(e)

import sys
import os
from PyQt5 import QtCore, QtGui, QtWidgets
from guifolder.gui import MainWindow
from main_paras import queueForGui, queueForResult, queueForCom

def spot_main():
    preStart()    
    Comm       =CommunicationThread(2,"Comm",queueForCom, queueForResult)
    TestMonitor=TestChipHandlerThread(3,"TCH",queueForCom, queueForGui, queueForResult)
    OnOff      =OnOffThread(4,"OnOff")

    Comm.start()
    OnOff.start()
    TestMonitor.start()

    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    app = QtWidgets.QApplication(sys.argv)
    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)
    window=MainWindow(qForGui = queueForGui)
    print('-- main window loaded --')
    rtn= app.exec_()
    print('main app return', rtn)
    print("App end.")
    queueForResult.put(CLOSE_NOW)
    queueForCom.put(CLOSE_NOW)
    TestMonitor.join()

    sys.exit(rtn)
    
if __name__ == "__main__":
    
    spot_main()



import cv2
import os
import random
import ntpath

from PIL import Image
import piexif


ROW = 0
COL = 1





IDEAL_BAR_WIDTH = 26
IDEAL_BAR_HEIGHT = 92



MAX_HEIGHT = 1600  ## after 90 degree rotation,
MAX_WIDTH  = 1200

#FIRST_CROP_COL = 80
FIRST_CROP_COL = 215
FIRST_CROP_HEIGHT = IDEAL_BAR_HEIGHT*(min([int(MAX_HEIGHT/IDEAL_BAR_HEIGHT), 8]))
FIRST_CROP_WIDTH  = IDEAL_BAR_WIDTH *(min([int((MAX_WIDTH-FIRST_CROP_COL)/IDEAL_BAR_WIDTH),  30]))
FIRST_CROP_ROW = int((MAX_HEIGHT - FIRST_CROP_HEIGHT)/2) #657



IDEAL_BAR_ROW_OFFSET  = int((FIRST_CROP_HEIGHT - IDEAL_BAR_HEIGHT)/2)
#IDEAL_BAR_COL_OFFSET  = 280
IDEAL_BAR_COL_OFFSET  = 380

CROP_TOP    =[FIRST_CROP_ROW, FIRST_CROP_COL]
CROP_BOTTOM =[FIRST_CROP_ROW+FIRST_CROP_HEIGHT, FIRST_CROP_COL+FIRST_CROP_WIDTH]


##FINAL_HEIGHT = 285
##FINAL_WIDTH  = 740
FINAL_HEIGHT = 320
FINAL_WIDTH  = 780
FINAL_ROW = int((MAX_HEIGHT - FINAL_HEIGHT)/2)
FINAL_COL = FIRST_CROP_COL

FINAL_BAR_ROW = int((FINAL_HEIGHT -IDEAL_BAR_HEIGHT)/2)
FINAL_BAR_COL = IDEAL_BAR_COL_OFFSET

##SECOND_BAR_TO_FIRST = 155
##SECOND_BAR_WIDTH = IDEAL_BAR_WIDTH+ 5

##SAMPLE_PIXELS = [[1,1], [100,100], [200,200]]
##
##
##TOP    = [0, IDEAL_BAR_COL_OFFSET - 150]   # row, col
##BOTTOM = [CROP_HEIGHT+EXTEND, IDEAL_BAR_COL_OFFSET + 240] # the range is from TOP  to [BOTTOM[ROW-1], BOTTOM[COL-1]]
##
##TARGET = [20, 10]   # height, width
##TARGET_HEIGHT = 20
##TARGET_WIDTH  = 10
##
##
##HEIGHT = 0
##WIDTH  =1
##
##def isLine(img, begin, end):
##    for c in range(begin[COL], end[COL]):
##        if img[begin[ROW], c] !=0:
##            return False
##    return True
##def isBlock(img, top, bottom):
##    for r in range(top[ROW], bottom[ROW]):
##        if not isLine(img, [r, top[COL]], [r, bottom[COL]]):
##            return False
##    return True
##
##def findTarget(img, top, bottom, target):
##    finalRow = -1
##    finalCol = -1
##    
##    print(top, bottom)
##
##    for c in range(top[COL], bottom[COL] - target[WIDTH]):
##        if finalCol != -1:
##            break;
##        for r in range(top[ROW], bottom[ROW] - target[HEIGHT]):
##            if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
##                finalCol = c
##                break;
##    
##    if finalCol == -1:
##        return -1,-1
##
##    print("got col offset ", finalCol)
##    middleR =r-(IDEAL_BAR_HEIGHT-target[HEIGHT])
##    print("middle r ", middleR)
##    for r in range(middleR,  middleR+ (IDEAL_BAR_HEIGHT-target[HEIGHT]) +1):
##        if finalRow != -1:
##            break;
##        for c in range(finalCol, finalCol+IDEAL_BAR_WIDTH-target[WIDTH]):
##            if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
##                finalRow = r
##                break;
##
##    return finalRow, finalCol
##
### def findTarget(img, top, bottom, target):
###     finalRow = -1
###     finalCol = -1
###     
###     for c in range(top[COL], bottom[COL] - target[WIDTH]):
###         for r in range(top[ROW], bottom[ROW] - target[HEIGHT]):
###             if isBlock(img, [r, c], [r+target[HEIGHT], c+target[WIDTH]]):
###                 finalCol = c
###                 finalRow = r
###                 break;
###     
###     return finalRow, finalCol
##
##def calibration(img,path):
##    try:
##        
##        gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
##        thresh = cv2.threshold(gray, 123, 255, cv2.THRESH_BINARY)[1]
##        kernel = cv2.getStructuringElement(cv2.MORPH_ELLIPSE, (7,7))
##        morph = cv2.morphologyEx(thresh, cv2.MORPH_OPEN, kernel)
##        letter = morph.copy()
##        finalRow, finalCol = findTarget(letter, TOP, BOTTOM, TARGET)
##        cv2.imwrite(os.path.join(path,'gray.jpg'), gray)
##        cv2.imwrite(os.path.join(path,'thresh.jpg'), thresh)
##        cv2.imwrite(os.path.join(path,'letter.jpg'), letter)
##    except Exception as e:
##        print ("calibration exception: ",e)
##        finalRow, finalCol =-1, -1
##    
##    if finalRow == -1 or finalCol == -1:
##        print("calibration failed!")
##        finalRow, finalCol =IDEAL_BAR_ROW_OFFSET+EXTEND, IDEAL_BAR_COL_OFFSET
##    return finalRow, finalCol
##    
##
def cr_size():
    return FIRST_CROP_HEIGHT, FIRST_CROP_WIDTH

def cr(img):
    newImg=cv2.rotate(img,cv2.ROTATE_90_COUNTERCLOCKWISE)
    cropImg=newImg[FIRST_CROP_ROW:FIRST_CROP_ROW+FIRST_CROP_HEIGHT, FIRST_CROP_COL:FIRST_CROP_COL+FIRST_CROP_WIDTH]
    return cropImg 

def crop_rotate(original_img):
    img = original_img
    if original_img.shape[:2] > cr_size():
        img = cr(original_img)
    return img
 
def final_save(finalImg, imageFile):
    height, width = finalImg.shape[:2]
    print(height, width)
    if height !=FINAL_HEIGHT or width!=FINAL_WIDTH:
        return False
    
    cv2.imwrite(imageFile, finalImg)
    
    my_exif_ifd = {
                piexif.ExifIFD.CameraOwnerName: u"Spot II",
                }
    exif_dict = {"Exif":my_exif_ifd}
    exif_bytes = piexif.dump(exif_dict)
    im = Image.open(imageFile)
    im.save(imageFile, exif=exif_bytes)
    im.close()
    return True


def cr_modified(img, m_y, m_x):
    newImg=cv2.rotate(img,cv2.ROTATE_90_COUNTERCLOCKWISE)
    final_row =FINAL_ROW + m_y
    final_col =FINAL_COL + m_x
    cropImg=newImg[final_row:final_row+FINAL_HEIGHT, final_col:final_col+FINAL_WIDTH]
    return cropImg 

#    print("Save image to ",imageFile)
    return True



import subprocess
import threading
from gpiozero import Button

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
#sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)

from define import *
import main_paras
from on_off.mainboard_pio import fanFullSpeedOn
powerButton = Button(POWER_BUTTON_PIN,True,None,None,POWER_BUTTON_HOLD_TIME)
def shutDown():
    print("shut down now")
    subprocess.Popen(['shutdown','-h','now'])

class OnOffThread (threading.Thread):
    def __init__(self, threadID, name):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name

    def run (self):
        cmd = 'cat /proc/cpuinfo | grep Serial | cut -d \' \' -f 2'
        main_paras.serial='LS2-'+subprocess.check_output([cmd], shell=True).decode("utf-8")
        main_paras.serial = main_paras.serial.replace('\n','')
        print(main_paras.serial)
        
        powerButton.when_held=shutDown #takePhoto
        fanFullSpeedOn()
            
if __name__ == "__main__":
    OnOff      =OnOffThread(4,"OnOff")

    OnOff.start()



import threading
import queue
import time
import os
import subprocess
from PyQt5 import QtCore, QtGui, QtWidgets
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
print(currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
print(parentdir)


from launcher import _Launcher

LAUNCHER_VERSION = 'spotii_launcher_1.04\r\n'
TIME_LIMIT = 100
CLOSE_EVENT = 'close'
JOB_DONE = 'job_done'

TASK_ONE_MILESTONE= 30
TASK_TWO_MILESTONE= 50
TASK_THREE_MILESTONE= 70
TASK_FOUR_MILESTONE= 90
TASK_FIVE_MILESTONE= 95
TASK_FINAL_MILESTONE= 98

class NotifyThread(QtCore.QThread):
    signal_to_Gui  = QtCore.pyqtSignal(object)
    signal_to_Thread = QtCore.pyqtSignal(object)
    signal_to_Window = QtCore.pyqtSignal(object)

class FunctionThread(QtCore.QThread):
    def __init__(self, emitThread):
        super(FunctionThread, self).__init__()
        self.emitThread=emitThread
        self.emitThread.signal_to_Thread.connect(self.signalHook)
        self.running=True
        self.done = False
    def signalHook(self,item):
        if item == CLOSE_EVENT:
            self.running = False
        elif item == JOB_DONE:
            self.done = True

class TimerThread(FunctionThread):
    def __init__(self, emitThread):
        super(TimerThread, self).__init__(emitThread)
    def run(self):                
        count = 0
        while count < TIME_LIMIT and self.running:
            count +=1
            #print("in TimerThread", count)
            if self.done:
                time.sleep(0.5)
            elif count < TASK_ONE_MILESTONE:
                time.sleep(0.1)
            elif count < TASK_TWO_MILESTONE:
                time.sleep(0.5)
            elif count < TASK_THREE_MILESTONE:
                time.sleep(0.9)
            elif count < TASK_FOUR_MILESTONE:
                time.sleep(1.5)
            elif count < TASK_FIVE_MILESTONE:
                time.sleep(5)
            else :
                time.sleep(15)
            
            
            self.emitThread.signal_to_Gui.emit(1)
        print('TimerThread done')
class JobThread(FunctionThread):
    def __init__(self, emitThread):
        super(JobThread, self).__init__(emitThread)
    def run(self):                
        #print("Start emit thread")
        count = 0
        time.sleep(0.1)
        self.emitThread.signal_to_Gui.emit([LAUNCHER_VERSION,0])
        while True:
            self.emitThread.signal_to_Gui.emit(['Checking...\r\n',1])
            upgrade ='Nothing'
            try:
#                upgrade=subprocess.check_output(['sudo','pip3','install','spotii','-U']).decode("utf-8")
                upgrade=subprocess.check_output(['pip3','install','spotii','-U']).decode("utf-8")
            except subprocess.CalledProcessError as e:
                print('subprocess error',e.output)
            except ConnectionError as e:
                print('connection error',e)
            except Exception as e:
                print('Exception',e)
            #time.sleep(10)
            #print('upgrade:',upgrade)
#             self.emitThread.signal_to_Gui.emit([upgrade,TASK_ONE_MILESTONE])
# 
# ##            if not self.running:
# ##                break;
#             self.emitThread.signal_to_Gui.emit(['Initializing...\r\n',TASK_ONE_MILESTONE+1])
            self.emitThread.signal_to_Gui.emit(['Starting...\r\n',TASK_FINAL_MILESTONE])
            self.emitThread.signal_to_Thread.emit(JOB_DONE)
            
            break;
        print('JobThread done')
            
class MyUi(_Launcher):
    def __init__(self, emitThread):
        super(MyUi, self).__init__()
        self.emitThread=emitThread
        self.emitThread.signal_to_Gui.connect(self.emitHook)
        self.emitThread.signal_to_Window.connect(self.windowSignalHook)

        self.timerThread=TimerThread(self.emitThread)
        self.timerThread.start()

        self.jobThread=JobThread(self.emitThread)
        self.jobThread.start()
        self.count=0
        self.initDone=False
 
    def setupParts(self):
        pass

    def emitHook(self,item):
        try:
            if type(item) == int:
                if item != TASK_FINAL_MILESTONE -1 :
                    self.count+=item
            else:
                self.count=item[1]
                self.label.setText(self.label.text()+item[0])
            self.progressBar.setProperty("value", self.count)
            if self.count == 100:
                print(self.count)
                self.emitThread.signal_to_Thread.emit(CLOSE_EVENT)
                self.initDone=True
                #self.close()
                QtWidgets.qApp.quit()
#                 self.emitThread.signal_to_Window.emit(CLOSE_EVENT)
        except Exception as e:
            print(e)
            
    def windowSignalHook(self, item):
        print('windowSignalHook',item)
        if item ==CLOSE_EVENT:
            self.emitThread.signal_to_Thread.emit(CLOSE_EVENT)
            
            #QtWidgets.qApp.quit()
            #time.sleep(1.5)
            self.initDone=True
            self.close()
    def status(self):
        return self.initDone
        

if __name__ == "__main__":
    import sys
    emitThread=NotifyThread()
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = MyUi(emitThread) ##QtWidgets.QMainWindow()
    
    MainWindow.show()
    returnValue =app.exec_()
    print('launcher return value :' ,returnValue)
    initialized = MainWindow.status()
    if returnValue == 0 and initialized:
        
        #MainWindow.close()
        try:
            from spotii import spot_main
        except Exception as e:
            print(e)
            from main import spot_main
        print('init done, start spot_main')
        spot_main()
        
    else:
        sys.exit(0)



from PyQt5 import Qt, QtCore, QtGui, QtWidgets
from PyQt5.QtCore import QDateTime
from PyQt5.QtWidgets import QDialog
from PyQt5.QtGui import QFont
import time
class MyToolButton(QtWidgets.QToolButton):
    def __init__(self, parent=None):
        super(MyToolButton,self).__init__(parent)
        self.activeIcon=None
        self.inactiveIcon=None
        self.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        #self.setAutoRaise(True)
        #self.setAutoFillBackground(True)

        self.enterTimeStamp=0
        self.notifyTimeStamp=0
        self.clicked.connect(self.beClicked)
        self.PopWindow=None
        self.popX=0
        self.popY=0
        
    def setup(self, PopWindow, x, y):
        try:
            print('setting up...')
            self.PopWindow=PopWindow
            self.popX=x
            self.popY=y
        except Exception as e:
            print(e)
        
    def beClicked(self):
        try:
            print('beClicked')
            if self.isChecked():
                if self.iconClickAgain():
                    self.clearNotify()
                    self.setChecked(False)
                else:
                    assert self.PopWindow != None
                    popUp= self.PopWindow()
                    popUp.move(self.popX, self.popY)
                    popUp.exec()
                    self.setChecked(False)
                    self.notify()            
        except Exception as e:
            print(e)
        
    def enterEvent(self, event):
        try:
            self.enterTimeStamp=time.time()
            #print("Mouse entered",self.enterTimeStamp)
            super(MyToolButton, self).enterEvent(event)
        except Exception as e:
            print(e)
##        self.setStyleSheet("QToolButton{background-color: rgba(0,21,59,255);}")
##        icon = QtGui.QIcon()
##        icon.addPixmap(self.activeIcon, QtGui.QIcon.Normal, QtGui.QIcon.Off)
##        self.setIcon(icon)
##        self.repaint()
##        # emit your signal
    def leaveEvent(self, event):
        try:
            #print("Mouse left",time.time())
            super(MyToolButton, self).leaveEvent(event)
        except Exception as e:
            print(e)
##        self.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
##        if self.isChecked():
##            return
##        icon = QtGui.QIcon()
##        icon.addPixmap(self.inactiveIcon, QtGui.QIcon.Normal, QtGui.QIcon.Off)
##        self.setIcon(icon)
##        self.repaint()
            
##    def actionEvent(self, event):
##        print('actionEvent', event)
##        mouceReleaseEvent
##        
##    def changedEvent(self, event):
##        print('changedEvent', event)
##        super(MyToolButton, self).changedEvent(event)
        
##    def hitButton(self, event):
##        print('hitButton', event)
##        super(MyToolButton, self).hitButton(event)
        
##    def moucePressEvent(self, event):
##        print('moucePressEvent', event)
##        super(MyToolButton, self).moucePressEvent(event)
##        
##    def mouceReleaseEvent(self, event):
##        print('mouceReleaseEvent', event)
##        super(MyToolButton, self).mouceReleaseEvent(event)

    def notify(self):
        try:
            self.notifyTimeStamp=time.time()
            #print('got it',self.notifyTimeStamp)
        except Exception as e:
            print(e)
    def clearNotify(self):
        self.notifyTimeStamp = 0
    def iconClickAgain(self):
        if self.notifyTimeStamp!=0 and self.enterTimeStamp!=0:
            if abs(self.enterTimeStamp - self.notifyTimeStamp) < 0.1 :
                return True
        return False



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)

parentdir = os.path.dirname(currentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)
import title_rc
from main_paras import mainChannelNotify, getDetectionMode
from define import *


class _CassetteTypeDialog(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_CassetteTypeDialog, self).__init__(parent)


        loadUi(os.path.join(currentdir,'cassette_type.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)

    def closeEvent(self,event):
        print("Pop dialog is closing")

    def config(self):
        try:
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.chip.clicked.connect(self.chip_selected)
            self.qr.clicked.connect(self.qr_selected)
            if getDetectionMode() == CASSETTE_DETECTION_MODE_AUTO:
                self.chip.setChecked(True)
            else:
                self.qr.setChecked(True)
            pass
        except Exception as error:
            print(error)



    def chip_selected(self):
        try:
            if self.chip.isChecked():
                print('chip checked')
                mainChannelNotify(MAIN_PARA_CASSETTE_TYPE_CHIP)
            else:
                print('chip unchecked')
            pass
        except Exception as error:
            print(error)

    def qr_selected(self):
        try:
            if self.qr.isChecked():
                print('qr checked')
                mainChannelNotify(MAIN_PARA_CASSETTE_TYPE_QR)
            else:
                print('qr unchecked')
            pass
        except Exception as error:
            print(error)

if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
    window=_CassetteTypeDialog()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import sys
import subprocess
import threading
import time
from datetime import datetime,timezone

if __name__ == "__main__":
    import sys, os, inspect
    currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
    parentdir = os.path.dirname(currentdir)
    sys.path.insert(0, parentdir)
    
from non_block_queue import NonBlockQue
from main_paras import getDetectionMode, getOperation, setOperation, queueForGui
from test_handler.i2c_lib import i2c_device
from test_handler.take_photo import takePhoto, TakePhotoProcedure
from define import *
import main_paras


class CassettePolling(threading.Thread):
    def __init__(self, slotIndex, i2c, camera, qResult, qCom, deviceQue):
        threading.Thread.__init__(self)
        self.slotIndex = slotIndex
        self.i2c = i2c
        self.camera = camera
        self.qResult = qResult
        self.qCom = qCom
        self.deviceQue=deviceQue
        self.stopTakingPhoto = threading.Event()
        
        
        self.deviceStatus = DEVICE_STATE_ORIGINAL
        
        self.takePhotoProcedure = None
        self.running = True
        self.qrcode_que = NonBlockQue()
        self.qrPollingStamp=0
        self.manual_sequence = MANUAL_OPERATION_START
        self.prevMode=None
        self.prevCassetteStatus=None
    def stopTakePhotoProcedure(self):
        if self.takePhotoProcedure != None and self.takePhotoProcedure.is_alive():
            print("stop take photo procedure")
            self.stopTakingPhoto.set()
            self.takePhotoProcedure.join()
            self.stopTakingPhoto.clear()
            
    def startTakePhotoProcedure(self,qr_code, responeQue):
        try:
            print('start taking photo procedure', qr_code)
            if qr_code != None:
                item=[self.slotIndex, DEVICE_STATE_TAKING_PHOTO, qr_code, 'Taking photo']
                print(item)
                self.notify(item)
            self.stopTakePhotoProcedure()
            self.takePhotoProcedure = TakePhotoProcedure(self.slotIndex, qr_code, self.camera, responeQue, self.stopTakingPhoto)
            self.takePhotoProcedure.start()
        except Exception as e:
            print(e)
        
    def run(self):
        self.periodPoll()
        while self.running:
            cmd=self.deviceQue.get()
            if cmd == PHOTO_TAKING_STOP:
                #print("stop command")
                self.stopTakePhotoProcedure()
            self.deviceQue.task_done()
        else:
            #self.stopTakePhotoProcedure()
            print('polling stop', self.slotIndex)
            
#        self.cameraTest(self.index, self.i2c, self.camera)

    def notify(self, item):
#         if self.slotIndex == 0:
#             print('deviceStatus',self.deviceStatus, 'new',item[1])
        if item == CLOSE_NOW:
            self.running=False
            self.deviceQue.put(PHOTO_TAKING_STOP)
            
        elif self.deviceStatus != item[1]:
            self.deviceStatus = item[1]
            if item[1] != DEVICE_STATE_CASSETTE_POLLED:
                #print('put in queque', item)
                self.qResult.put(item)

    def cassetteOut(self):
        for i in range(5):
            i2cInstant=i2c_device(self.i2c,I2C_PORT)
            status=i2cInstant.read_data(I2C_MEM_STATUS)|0x80 #There should be bug on daughter board I2c function. sometimes missed bit 7.
            
            if status & CASSETTE_STATUS_FLAG == 0:
                print(time.strftime('%Y%m%d%H%M%S'), "Wrong flag, re-read.", self.slotIndex, hex(status))
                time.sleep(2)
                continue
            
            elif status == DEVICE_STATE_CASSETTE_EMPTY:
                break
            else:
                break
        rtn = False
#         if(self.slotIndex == 0):
#             print(self.prevCassetteStatus, status)
        if self.prevCassetteStatus != status:
            self.prevCassetteStatus=status
            if status == DEVICE_STATE_CASSETTE_EMPTY:
                rtn = True
            
        return rtn

    def manualQr(self):
        status = DEVICE_STATE_CASSETTE_QR
        qr = None
#         if self.slotIndex ==0:
#             print('slot', self.slotIndex, 'Operation',self.manual_sequence)
            
        if self.cassetteOut() and self.manual_sequence != MANUAL_OPERATION_TEST:
            setOperation(self.slotIndex, MANUAL_OPERATION_START)
#            queueForGui.put([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'cassette out'])
#            return status,qr
        
        self.manual_sequence = getOperation(self.slotIndex)
        
        if self.manual_sequence  == MANUAL_OPERATION_START:
            self.stopTakePhotoProcedure()
            self.notify([self.slotIndex, DEVICE_STATE_MANUAL_SCAN, '', 'manual scan'])
            setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING)
        if self.manual_sequence  == MANUAL_OPERATION_START_WAITING:
            pass
        elif self.manual_sequence  == MANUAL_OPERATION_SCAN:
            self.startTakePhotoProcedure(None,self.qrcode_que)
            self.qrPollingStamp=time.time()
            setOperation(self.slotIndex, MANUAL_OPERATION_GETTING_QR)
        elif self.manual_sequence  == MANUAL_OPERATION_GETTING_QR:
            qr = self.qrcode_que.get()
            if qr!=None:
                if qr != NON_QR:
                    print('got qr from image',qr)
                    self.qrCode = qr
                    setOperation(self.slotIndex, MANUAL_OPERATION_TEST)
                    self.notify([self.slotIndex, DEVICE_STATE_MANUAL_FLIP, self.qrCode, 'Waiting test'])
                else:
                    self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'invalid qr'])
                    setOperation(self.slotIndex, MANUAL_OPERATION_RESTART)
                    
            elif (time.time()- self.qrPollingStamp) > QR_POLLING_TIMEOUT:
                print('getting qr time out')
                self.notify([self.slotIndex, DEVICE_STATE_MANUAL_INVALID_QR, '', 'scan timeout'])
                setOperation(self.slotIndex, MANUAL_OPERATION_RESTART)
            else:
                print('reading qr...')
        elif self.manual_sequence  == MANUAL_OPERATION_TEST:
            pass
        elif self.manual_sequence  == MANUAL_OPERATION_START_TESTING:
            status = DEVICE_STATE_CASSETTE_VALID
            qr = self.qrCode
            setOperation(self.slotIndex, MANUAL_OPERATION_START_WAITING_RESULT)  ##waiting for result
        elif self.manual_sequence  == MANUAL_OPERATION_START_WAITING_RESULT:
            pass
        elif self.manual_sequence == MANUAL_OPERATION_RESTART:
            pass
        #print('manual qr')
        return status, qr
        

    def autoQr(self):
        try:
            qrCode=''
            status=DEVICE_STATE_CASSETTE_EMPTY
            for i in range(5):                
                i2cInstant=i2c_device(self.i2c,I2C_PORT)
                status=i2cInstant.read_data(I2C_MEM_STATUS)|0x80 #There should be bug on daughter board I2c function. sometimes missed bit 7.
                
                if self.slotIndex == 0 and status!=DEVICE_STATE_CASSETTE_POLLED:
                    print(hex(status), time.strftime('%Y%m%d%H%M%S'))
                qrCode=''
                if(status == DEVICE_STATE_CASSETTE_VALID):
                    qr=i2cInstant.read_block_data(I2C_MEM_ID, 9)
                    qrCode=(''.join(chr(x) for x in qr))
                    if not qrCode.isalnum():
                        print(time.strftime('%Y%m%d%H%M%S'), "qrCode crashed", self.slotIndex,qrCode)
                        time.sleep(2)
                        continue
                    break;
                elif status & CASSETTE_STATUS_FLAG == 0:
                    print(time.strftime('%Y%m%d%H%M%S'), "Wrong flag, re-read.", self.slotIndex, hex(status))
                    time.sleep(2)
                    continue
                else:
                    #print("Cassette status:", self.index, hex(status))
                    break;
                    
            #if status != DEVICE_STATE_CASSETTE_POLLED and status in CASSETTE_STATUS:
            if status == DEVICE_STATE_CASSETTE_VALID:
                i2cInstant.write_cmd_arg(I2C_MEM_ACK, status)
                print("Write back ACK")
                
            return status,qrCode
        except Exception as err:
            print("CassettePollingException: ", err)
            return DEVICE_STATE_SUBSYS_EXCEPTION, None
        
    def getQr(self):
        currentMode=getDetectionMode()
        if self.prevMode!=None and self.prevMode!=currentMode:
            print('mode changed')
            self.stopTakePhotoProcedure()
        self.prevMode=currentMode
        if currentMode == CASSETTE_DETECTION_MODE_AUTO:
            return self.autoQr()
        return self.manualQr()
    

##self.notifyQue.put([self.slotNo, int(parsing[RSLT][RCODE]), self.cassetteId, parsing[RSLT][MSSG], recordId[self.slotNo]])
    def deviceDeal(self):  # return [device_slotIndex, state, QRcode, message]
        if self.camera == INVALID_DEVICE_INDEX:
            self.notify([self.slotIndex, DEVICE_STATE_CAMERA_ERROR, '', 'Camera error'])
            return 
        if self.i2c == INVALID_DEVICE_INDEX:
            self.notify([self.slotIndex, DEVICE_STATE_I2C_ERROR, '', 'i2c error'])
            return
        status,qr_code =self.getQr();
        if(status == DEVICE_STATE_CASSETTE_POLLED):
            self.notify( [self.slotIndex, DEVICE_STATE_CASSETTE_POLLED, '', 'no change'])
        elif(status == DEVICE_STATE_CASSETTE_VALID):
            if not main_paras.signedIn():
                main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
            else:
                self.startTakePhotoProcedure(qr_code,self.qCom)
        elif(status == DEVICE_STATE_CASSETTE_QR):
#             if self.slotIndex == 0:
#                 print('manual waiting qr')
            pass            
        else:
            if (not main_paras.signedIn()) and status != DEVICE_STATE_CASSETTE_EMPTY:
                main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
            else:
                self.stopTakePhotoProcedure()
                self.notify([self.slotIndex, status, '','Cassette error'])
            
    def periodPoll(self):
        #if self.slotIndex == 0:
        #print("Period poll", time.strftime('%Y%m%d%H%M%S'))
        if self.running:
            self.deviceDeal()
            threading.Timer(DEVICE_POLLING_TIME, self.periodPoll).start()
        else:
            print('periodPoll stop', self.slotIndex)
            
        
    def cameraTest(self):
        photoFile=takePhoto(self.camera, "cameraTest"+'_'+str(self.slotIndex))
        
if __name__ == "__main__":
    import queue
    from main_paras import setDetectionMode
    
    setDetectionMode(CASSETTE_DETECTION_MODE_MANUAL)

    qForGui=queue.Queue()
    qForCom=queue.Queue()
    deviceQue=queue.Queue()
    polling_0= CassettePolling(0, 80, 0, qForGui, qForCom,deviceQue)
    polling_2= CassettePolling(1, 81, 2, qForGui, qForCom,deviceQue)
    polling_4= CassettePolling(2, 82, 4, qForGui, qForCom,deviceQue)
    polling_6= CassettePolling(3, 83, 6, qForGui, qForCom,deviceQue)
    polling_8= CassettePolling(4, 84, 8, qForGui, qForCom,deviceQue)
    polling_0.start()
    polling_2.start()
    polling_4.start()
    polling_6.start()
    polling_8.start()
    
        



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi
import subprocess
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)

parentdir = os.path.dirname(currentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)
import title_rc
from main_paras import mainChannelNotify, getDetectionMode
from define import *


class _Brightness(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_Brightness, self).__init__(parent)


        loadUi(os.path.join(currentdir,'brightness.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)

    def closeEvent(self,event):
        print("_Brightness is closing")

    def config(self):
        try:
            self.slider.setMaximum(10)
            self.slider.setValue(8)
            subprocess.call(['sudo /home/pi/set_backlight.dat',str(8)],shell=True)
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.slider.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.slider.valueChanged.connect(self.slider_hook)
            pass
        except Exception as error:
            print(error)

    def slider_hook(self, value):
        try:
            cmd ='sudo /home/pi/set_backlight.dat '+str(value)
            print(cmd)
            subprocess.call([cmd],shell=True)
            print(value)
            pass
        except Exception as error:
            print(error)
if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    window=_Brightness()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

import title_rc
from main_paras import getMainTopLeft
from main_paras import api_result_que

import main_paras
from define import *
#from create_new_account import _CreateAccount
import create_new_account
import forgot_password
import test_info
import wrong_password
from vkeyboard import handleVisibleChanged

class _SignIn(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_SignIn, self).__init__(parent)

        loadUi(os.path.join(currentdir,'sign_in.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        self.setWindowFlags(flags)
        self.last_scroll_value=0
        self.original = True

    def scrolled(self):
        try:
            diff =(self.last_scroll_value - self.scroll.value())*10
            self.last_scroll_value=self.scroll.value()
            print(self.scroll.value())
            children= self.widget.findChildren(QtWidgets.QWidget)
            for child in children:
                if child != self.scroll:
                    child.move(child.pos().x(),child.pos().y()+diff)
            self.repaint()
        except Exception as error:
            print(error)

    def keyUp(self):
        print('keyUp got emit')
        if self.original:
            self.original = False
            self.scroll.setVisible(True)
            self.move(0,0)
            self.repaint()        

    def config(self):
        try:
            self.scroll.setMaximum(20)
            self.scroll.valueChanged.connect(self.scrolled)
            self.scroll.hide()
            main_paras.keyboard_up.signal.connect(self.keyUp)

            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.create_account.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.sign_in_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.forgot_psw.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            
            self.create_account.clicked.connect(self.create_account_hook)
            self.sign_in_bt.clicked.connect(self.sign_in_bt_hook)
            self.forgot_psw.clicked.connect(self.forgot_psw_hook)
            
            main_paras.keyboard_up.signal.connect(self.keyUp)

            pass
        except Exception as error:
            print(error)

    def create_account_hook(self):
        try:
            global popUp
            self.close()
            popUp = create_new_account._CreateAccount()
            x,y = getMainTopLeft()
            popUp.move(x,y)
            popUp.show()
            pass
        except Exception as error:
            print(error)
#[NON_SLOT_INDEX, SIGN_IN_SUCCESS, parsing[RSLT][TKEN], '']
#[NON_SLOT_INDEX, SIGN_IN_FAIL,  parsing[CODE], parsing[DESC]]
    def sign_in_bt_hook(self):
        global popUp
        try:
            user = self.email.text()
            psw =  self.password.text()
            if user != '' and psw != '':
                main_paras.queueForCom.put([SIGN_IN, user, psw])

                response=main_paras.api_result_que.getTimeout(10)
                if response == None:
                    popUp = wrong_password._WrongPassword()
                    popUp.setMessage(self.tr("Check network."))
                elif response[1] == SIGN_IN_FAIL:
                    popUp = wrong_password._WrongPassword()
                elif response[1] == SIGN_IN_SUCCESS:
                    main_paras.sign_in_token = response[2]
                    main_paras.sign_in_user = user
                    
                    if user == 'feng.gao@laipac.com':
                        main_paras.test_place='Office'
                        main_paras.test_city = 'Markham'
                        main_paras.test_country = 'Canada'
                        main_paras.test_provider = 'Laipac'
                    
                    self.close()
                    popUp = test_info._TestInfo()

                x,y = getMainTopLeft()
                popUp.move(x,y)
                popUp.show()
                
           
        except Exception as error:
            print(error)
    def forgot_psw_hook(self):
        try:
            global popUp
            self.close()
            popUp = forgot_password._ForgotPassword()
            x,y = getMainTopLeft()
            popUp.move(x,y)
            #popUp.exec()
            #popUp.setModal(True)
            popUp.show()
            
        except Exception as error:
            print(error)
    def closeEvent(self,event):
        print("_SignIn is closing")
        

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"
    
    app = QtWidgets.QApplication(sys.argv)
    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)
##    app.installTranslator(trans)

    QtWidgets.QMainWindow
    window=_SignIn()
    
    window.show()
    print('sub window shown')
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
import time
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

import title_rc
from main_paras import getMainTopLeft, queueForGui
import main_paras
from wifi_item import _WifiItem
import wifi_setting
import wifi_password

##for self.interface
##['Enabled', 'Connected', 'Dedicated', 'Wi-Fi']
##      0          1           2           3
class _WifiList(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_WifiList, self).__init__(parent)
        loadUi(os.path.join(currentdir,'wifi_list.ui'),self)
        self.timer = QtCore.QTimer()
        self.timer.timeout.connect(self.interfaceMonitor)
        self.pollingTimer = QtCore.QTimer()
        self.pollingTimer.timeout.connect(self.inputPolling)
        
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint  | QtCore.Qt.Popup)
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)

    def closeEvent(self,event):
        print("_WifiList is closing")
        

    def config(self):
        try:
            self.interface = wifi_setting.wifiInterface()
            self.ssid = wifi_setting.wifiSsid()
            w_list=wifi_setting.wifiList()
            
            item= QtWidgets.QListWidgetItem()
            self.list.addItem(item)
            self.list.item(0).setForeground(QtCore.Qt.white)            
            if self.interface[0] == 'Enabled':
                self.list.item(0).setText(self.tr('Turn Off Wi-Fi'))
            else:
                self.list.item(0).setText(self.tr('Turn  On Wi-Fi'))
                w_list=[]

            print(self.interface)
            print(self.ssid)
            print(w_list)
            for each in w_list:
                item= QtWidgets.QListWidgetItem()
                self.list.addItem(item)
                element =_WifiItem()
                if each[0] == self.ssid:
                    self.name_highlight(element.name)
                    self.connected_item = item
                else:
                    self.name_normal(element.name)
                element.name.setText(each[0])
                if each[1] == 'Open':
                    element.security.setStyleSheet('.QLabel{background-image: url(:/wifi/wifi_folder/un_protected.png);background-color: transparent; border:0; color :white}')
                else:
                    element.security.setStyleSheet('.QLabel{background-image: url(:/wifi/wifi_folder/protected.png);background-color: transparent; border:0; color :white}')
                signal=float(each[2].strip('%'))
                if signal > 75:
                    icon = 4
                elif signal > 50:
                    icon = 3
                elif signal > 25:
                    icon = 2
                elif signal > 5:
                    icon = 1
                else:
                    icon = 0
                element.signal.setStyleSheet('.QLabel{background-image: url(:/wifi/wifi_folder/wi-fi_'+str(icon)+'.png);background-color: transparent; border:0; color :white}')
                self.list.setItemWidget(item,element)
            self.list.itemClicked.connect(self.item_click_hook)
        except Exception as error:
            print(error)

    def name_highlight(self, name):
        name.setStyleSheet('.QLabel{background-color: transparent; border:0; color : rgb(248,176,0)}')
        
    def name_normal(self, name):
        name.setStyleSheet('.QLabel{background-color: transparent; border:0; color :white}')
        
    def item_click_hook(self,item):
        try:
            index = self.list.row(item)
            print(index)
            if index == 0: ## Turn on/off
                if self.interface[0] == 'Enabled':
                    #queueForGui.put('turn off wifi')
                    print('turn off wifi')
                    wifi_setting.wifiTurnOff(self.interface[3])
                    self.timer.start(1000)
                else:
                    #queueForGui.put('turn on wifi')
                    print('turn on wifi')
                    wifi_setting.wifiTurnOn(self.interface[3])
                    self.timer.start(6000)
            else:
                newWifiName=self.list.itemWidget(item).name
                global popUp
                popUp = wifi_password._WifiPassword()
                x,y = getMainTopLeft()
                popUp.setName(newWifiName.text())
                popUp.move(x,y)
                popUp.show()
                #print(self.list.itemWidget(item).name.text())
                #print('current connected', self.list.itemWidget(self.connected_item).name.text())
#                 try:
#                     self.name_normal(self.list.itemWidget(self.connected_item).name)
#                 except Exception as err:
#                     print(err)
# 
#                 newWifiName=self.list.itemWidget(item).name
#                 if wifi_setting.wifiConnect(newWifiName.text()):
#                     self.connected_item = item
#                     self.name_highlight(self.list.itemWidget(item).name)
#                 else:
#                     global popUp
#                     popUp = wifi_password._WifiPassword()
#                     x,y = getMainTopLeft()
#                     popUp.setName(newWifiName.text())
#                     popUp.move(x,y)
#                     popUp.show()
#                     main_paras.type_in_que.clear()
#                     self.pollingTimer.start(200)
#                         isSet, newPsw = popUp.result()
#                         if isSet:
#                             print(isSet, newPsw)
#                             if wifi_setting.wifiConnect(newWifiName.text(),newPsw):
#                                 self.connected_item = item
#                                 self.name_highlight(self.list.itemWidget(item).name)
#                                 break;
#                             else:
#                                 popUp = _WrongPassword()
#                                 x,y = getMainTopLeft()
#                                 popUp.move(x,y)
#                                 popUp.exec()
#                         else:
#                             break;
        except Exception as error:
            print(error)
            
            
    
    def interfaceMonitor(self):
        try:
            newState=wifi_setting.wifiInterface()
            print(newState)
            if newState == None:
                print('interfaceMonitor','wrong!')
                self.timer.stop()
            
            if(newState[0]!=self.interface[0]):
                print('state changed')
                self.timer.stop()
                self.inerface = newState
                self.list.clear()
                self.config()
        except Exception as e:
            print('interfaceMonitor',e)
            
    def inputPolling(self):
        try:
            inputValue = main_paras.type_in_que.get()
            if inputValue!=None:                
                print(inputValue)
#                 if isSet:
#                     print(isSet, newPsw)
#                     if wifi_setting.wifiConnect(newWifiName.text(),newPsw):
#                         self.connected_item = item
#                         self.name_highlight(self.list.itemWidget(item).name)
#                         break;
#                     else:
#                         popUp = _WrongPassword()
#                         x,y = getMainTopLeft()
#                         popUp.move(x,y)
#                         popUp.exec()
#                 else:
#                     break;
                
                self.pollingTimer.stop()
                self.list.clear()
                self.config()
        except Exception as e:
            print('inputPolling',e)

if __name__ == "__main__":
    from PyQt5.QtCore import QTranslator
    import sys
##    trans=QTranslator()
##    trans.load("setting_wrap.qm")
    

    
    app = QtWidgets.QApplication(sys.argv)
##    app.installTranslator(trans)

    QtWidgets.QMainWindow
    window=_WifiList()
    window.show()
    
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
import time
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi
import subprocess
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
import title_rc

#myprocess =None
class _Play(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_Play, self).__init__(parent)
        loadUi(os.path.join(currentdir,'video.ui'),self)
        self.pollingTimer = QtCore.QTimer()
        self.process = None
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        QtCore.QTimer.singleShot(0, self.play)
 
    def config(self):
        try:
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close_now)
            self.pollingTimer.timeout.connect(self.processPolling)
            
        except Exception as error:
            print(error)
    def close_now(self):
        try:
            #myprocess.stdin.write(b'q')
            #self.myprocess.kill()
            #self.myprocess.terminate()
            subprocess.call(['pkill','omx'])
            self.close()
        except Exception as error:
            print(error)
    def play(self):
#        omxplayer -o local --win "0 0 470 262" 2.mp4
        #global myprocess
#        myprocess = subprocess.Popen(['omxplayer','-b','-o','local','--win','\"0 100 470 272\"','/home/pi/vids/2.mp4'],
        self.process=subprocess.Popen(['omxplayer','-o','local','--win','0 30 480 272','/home/pi/app/spotii/launcher/look_spot_2.mp4'],
                                     stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE, close_fds=True)
        print(self.process.poll())
#        self.myprocess = subprocess.Popen(['omxplayer','-b','/home/pi/vids/2.mp4'],stdin=subprocess.PIPE)
        self.pollingTimer.start(1)
    def processPolling(self):
        
        if self.process.poll() != None:
            print('process done', self.process.poll())
            self.pollingTimer.stop()
            self.close()

if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
    play=_Play()
    
    drtn=play.exec()
    print('pop dialog end',drtn)
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)

import title_rc
#from main_paras import mainChannelNotify, getDetectionMode, setOperation
from main_paras import getDetectionMode, setOperation
from define import *


class SlotPage(QtWidgets.QWidget):
    def __init__(self,parent=None):
        super(SlotPage, self).__init__(parent)

        loadUi(os.path.join(currentdir,'slotPage.ui'),self)
        self.config()
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        self.resize(96, 224)
        self.slot =0
        self.page =0
    def setDetail(self,slot,page):
        try:
            self.slot=slot+1
            self.page=page
            if self.page>=SLOT_STATUS_DETECTING and self.page<=SLOT_STATUS_INVALID :
                self.button.hide()
                self.number.setText(str(self.slot))
                if self.page != SLOT_STATUS_DETECTING:
                    #print('hide timer')
                    self.timer.hide()
            elif self.page>=SLOT_STATUS_SCAN and self.page<=SLOT_STATUS_INVALID_QR :
                self.id.hide()
                self.timer.hide()
                self.button.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            else:
                self.id.hide()
                self.timer.hide()
                self.button.hide()
                
        except Exception as error:
            print(error)
    def buttonHook(self, hookFunction):
        if hookFunction!=None:
            self.button.clicked.connect(hookFunction)
    def config(self):
        try:
            #self.id.lower()
            #self.timer.lower()
            
            pass
        except Exception as error:
            print(error)
            
    def button_click(self):
        try:
            print('slot', self.slot, 'page', self.page)
            setOperation(self.slot-1, self.page)
                
        except Exception as error:
            print(error)


if __name__ == "__main__":
    import sys
    
    app = QtWidgets.QApplication(sys.argv)

    QtWidgets.QMainWindow
    window=SlotPage()
    window.show()
    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)
